# frozen_string_literal: true

require_relative 'spec_helper'
require 'awesome_print'
require 'byebug'

VaultHelper = Sambot::Testing::VaultHelper
Fixtures = Sambot::Testing::Fixtures

RSpec.describe Sambot::Testing::VaultHelper do

  before(:each) do
    `docker-compose -p local down`
    `docker-compose -p local up -d`
    VaultHelper.setup
    ::Vault.configure do |config|
      config.address = 'http://127.0.0.1:8200'
      config.token = 'root'
      config.ssl_verify = false
    end
  end

  after(:each) do
    `docker-compose down`
  end

  context '.setup()' do

    it 'sets up Vault correctly' do
      mounts = ::Vault.sys.mounts
      expect(mounts[:"dev/common"]).to_not be_nil
    end

  end

  context '.load_secrets()' do

    it 'can save multiple keys' do
      config = Sambot::Config.read
      VaultHelper.load_secrets(config)
      secret = VaultHelper.read_path('dev/nightswatch/gcs/backupcreds')
      expect(secret.data[:access_key]).to_not be nil
      expect(secret.data[:secret_key]).to_not be nil
    end

  end

  context '.generate_wrapped_token()' do

    it 'generates the correct token' do
      wrapped_token = VaultHelper.generate_wrapped_token
      access_token = ::Vault.logical.unwrap(wrapped_token)
      expect(access_token.auth.renewable?).to be true
      expect(access_token.auth.lease_duration).to eql(2764800)
    end

    it 'generates a renewable token' do
      wrapped_token = VaultHelper.generate_wrapped_token
      access_token = ::Vault.logical.unwrap(wrapped_token)
      ::Vault.configure do |config|
        config.token = access_token.auth.client_token
      end
      ::Vault.auth_token.renew_self
    end

  end

end
