# frozen_string_literal: true

require 'thor/hollaback'

class Thor
  module Shell
    class Basic
      def print_wrapped(message, options = {})
        indent = options[:indent] || 0
        width = 100 - indent
        paras = message.split("\n\n")

        paras.map! do |unwrapped|
          unwrapped.strip.tr("\n", ' ').squeeze(' ').gsub(/.{1,#{width}}(?:\s|\Z)/) { ($& + 5.chr).gsub(/\n\005/, "\n").gsub(/\005/, "\n") }
        end

        paras.each do |para|
          para.split("\n").each do |line|
            stdout.puts line.insert(0, ' ' * indent)
          end
          stdout.puts unless para == paras.last
        end
      end
    end
  end
end

class Thor
  module Shell
    class Color < Basic
      GRAY     = "\e[90m"
    end
  end
end


class Thor
  class << self
    def command_help(shell, command_name)
      meth = normalize_command_name(command_name)
      command = all_commands[meth]
      handle_no_command_error(meth) unless command
      shell.say
      shell.say('  Usage:', :green)
      shell.say
      shell.say "  sambot #{command_name} "
      shell.say
      shell.say
      class_options_help(shell, nil => command.options.values)
      shell.say '  Description:', :green
      shell.say
      shell.print_wrapped(docs(command_name.to_s), indent: 2)
      shell.say
    end
  end
end

module Sambot
  class BaseCommand < Thor

    before :check_version

    no_commands do

      def execute
        Runtime.ensure_latest
        yield
      rescue ApplicationError => e
        UI.error(e.message)
      end

      def self.docs(path)
        File.read(File.join(File.dirname(__FILE__), '/docs', path + '.txt'))
      end

    end

  end
end
