# frozen_string_literal: true

require 'erubis'

module Sambot
  module Chef
    class Metadata

      class << self

        GENERATED_FILES = ['metadata.rb', 'Berksfile.lock'].freeze

        def clean
          GENERATED_FILES.each do |filename|
            FS.delete(filename)
          end
        end

        def generate(config, dest = 'metadata.rb')
          write({
            'cookbook_name' => config.name,
            'cookbook_platforms' => config.available_platforms,
            'cookbook_version' => config.version,
            'cookbook_description' => config.description,
            'cookbook_dependencies' => config.dependencies,
            'cookbook_gems' => config.gems
          }, dest)
        end

        private

        def write(ctx, dest)
          Sambot::Template.new('metadata.rb.erb').write(ctx, dest)
          UI.debug('A new metadata.rb file has been generated.')
        end

      end

    end
  end
end
