# frozen_string_literal: true

module Sambot
  module Chef
    class Roles

      class << self

        ROLE_COOKBOOK_ORGANIZATION = 'ads-role-cookbooks'
        COOKBOOK_CONFIG = '.config.yml'

        def pin_cookbook_version(dependency_name, version = nil, role_name = nil)
          raise 'No dependency name provided' unless dependency_name
          roles = role_name ? [role_name] : list_roles
          roles.each do |role|
            update_dependency_version(repository, dependency_name, version)
          end
        end

        def update_dependency_version(repository, dependency_name, version)
          file = SourceControl.get_file(ROLE_COOKBOOK_ORGANIZATION, repository, COOKBOOK_CONFIG)
          config = update_config(file, dependency_name, version)
          config ? apply_changes(config, repository, file) : false
        end

        def list_roles
          SourceControl.list_organization_repositories(ROLE_COOKBOOK_ORGANIZATION)
        end

        def update_config(file, dependency, version)
          body = Base64.decode64(file.content)
          new_contents = body.lines.map do |line|
            line.match(/^\s*- #{dependency}/) ? update_line(line, dependency, version) : line
          end.join
          new_contents == body.lines.join ? nil : new_contents
        end

        private

        def update_line(val, dependency, version)
          val
        end

        def apply_changes(contents, repository, file)
          puts 'Not stubbed'
          raise 'error'
          msg = "Updated cookbook dependency #{dependency_name} to #{version}"
          SourceControl.edit_file(ROLE_COOKBOOK_ORGANIZATION, repository, COOKBOOK_CONFIG, contents, file, msg)
          return true
        end

      end
    end
  end
end
