# frozen_string_literal: true

require 'ridley'
require 'json'

module Sambot
  module Chef
    class Server

      SHORT_NAMES = {
        'wsus' => 'WSUS',
        'nginx-proxy' => 'PRXY',
        'jetstream' => 'JTS',
        'task-scheduler' => 'TASKS',
        'queue-service' => 'QUE',
        'skylight' => 'SKY',
        'prometheus' => 'PRT',
        'octopus' => 'OCTO',
        'vault' => 'VAULT',
        'consul' => 'CONSUL',
        'rabbitmq' => 'RMQ',
        'etcd' => 'ETCD',
        'teamcity-agent' => 'TCA',
        'teamcity-server' => 'TCS',
        'bastion' =>   'BST',
        'base' => 'BASE',
        'grafana' => 'MON'
      }.freeze

      def initialize(ridley = nil)
        @ridley = ridley || Ridley.new(
          server_url: "https://chef.brighter.io/organizations/#{ENV['CHEF_ORGANIZATION']}",
          client_name: ENV['CHEF_CLIENT_NAME'],
          client_key: ENV['CHEF_CLIENT_KEY'],
          proxy: ENV['FIXIE_URL']
        )
      end

      def cookbooks
        @cookbooks ||= @ridley.cookbook.all.select { |x| x =~ /as-/ }.keys.sort
      end

      def roles
        cookbooks.select { |x| x =~ /role/ }
      end

      def find_role_name(cookbook)
        naive_name = cookbook.gsub(/as-role-/, '').gsub(/as-app-role-/, '')
        if SHORT_NAMES.key?(naive_name)
          SHORT_NAMES[naive_name]
        else
          raise 'Could not generate an instance name'
        end
      end

    end
  end
end
