# frozen_string_literal: true

require_relative 'base_command'

module Sambot
  class CLI < BaseCommand

    desc 'checkout', 'Checks out or updates all the repositories in a given organization'
    def checkout(organization, dir)
      execute do
        Dir.chdir(dir) do
          SourceControl.checkout(organization)
        end
      end
    end

    desc 'clean', 'Remove all generated build files from a Chef cookbook'
    def clean; execute { Chef::Cookbook.clean } end

    desc 'up', 'Setup the Docker environment for testing cookbooks'
    def up; execute { Sambot::Tasks::Up.new.run(options) } end

    desc 'down', 'Destroy the Docker environment for testing cookbooks'
    def down; execute { Sambot::Tasks::Down.new.run(options) } end

    desc 'test', 'Test a cookbook using the Docker environment'
    def test; execute { Sambot::Tasks::Test.new.run(options) } end

    desc 'populate', 'Populates Vault and Consul with seed data'
    def populate; execute { Sambot::Tasks::Populate.new.run(options)  } end

    desc 'bump', 'Bump the patch version of a cookbook'
    def bump; execute { Chef::Cookbook.bump } end

    desc 'build', 'Builds a Chef cookbook from its configuration file'
    option :local, type: :boolean
    option :google, type: :boolean
    option :rackspace, type: :boolean
    option :docker, type: :boolean
    def build; execute { Sambot::Tasks::Build.new.run(options) } end

    desc 'create', 'Creates a new Chef cookbook'
    def create; execute { Sambot::Tasks::Create.new.run(options) } end

    desc 'version', 'Gives the cookbook version as a TeamCity service message'
    def version; execute { Sambot::Tasks::Version.new.run(options) } end

    desc 'verify', 'Ensures all supporting resources i.e. TeamCity build and Git repository are created and the git origin is pointing to the correct URL'
    def verify; execute { Sambot::Tasks::Verify.new.run(options) } end

  end
end
