# frozen_string_literal: true

require 'pry'
require 'github_api'
require 'git'

module Sambot
  class SourceControl

    class << self

      ET_GITHUB_API = 'https://github.exacttarget.com/api/v3'
      ET_GITHUB = 'https://github.exacttarget.com'
      ET_GITHUB_HOST = 'github.exacttarget.com'
      WRAPPER_COOKBOOKS = 'ads-wrapper-cookbooks'
      ROLE_COOKBOOKS = 'ads-role-cookbooks'

      def set_git_remote(config)
        target = identify_repository(config)
        cmd = "git remote set-url origin git@#{ET_GITHUB_HOST}:#{target[:organization]}/#{target[:name]}"
        UI.info("Running the following command: #{cmd}")
        `#{cmd}`
      end

      def add_deploy_key(config)
        # Create deploy key
        # Add it to Vault
        # Run Chef-Client against TeamCity
      end

      def create_repository(config)
        target = identify_repository(config)
        if api.repos.get user: target[:organization], repo: target[:name]
          UI.info("The repository #{target[:organization]}/#{target[:name]} exists and will not be recreated")
          return 1
        else
          api.repos.create "name": target[:name], org: target[:organization],
              "private": false,
              "has_issues": true,
              "has_wiki": false,
              "has_downloads": true
            UI.info("The repository #{target[:organization]}/#{target[:name]} has been created")
          return 0
        end
      end

      def delete_repository(config)
        target = identify_repository(config)
        if api.repos.get "#{target[:organization]}/#{target[:name]}"
          UI.info("The repository #{target[:organization]}/#{arget[:name]} does not exist and will not be deleted")
          return 1
        else
          api.repos.delete organization, repo
          return 0
        end
      end

      def checkout(organization)
        repositories = list_organization_repositories(organization)
        repositories.each do |repository|
          if Dir.exist?(repository.name)
            UI.info("#{repository.name} already exists and will be updated")
            Dir.chdir(repository.name) do
              `git pull`
            end
          else
            `git clone #{repository.ssh_url}`
          end
        end
      end

      def list_organization_repositories(organization)
        api.repos.list org: organization
      end

      def get_file(organization, repository, path)
        contents_api.find user: organization, repo: repository, path: path
      end

      def edit_file(organization, repository, path, contents, file, msg)
        contents_api.update organization, repository, path,
          content: contents,
          path: path,
          message: msg,
          sha: file.sha
      end

      private

      def identify_repository(config)
        {
          name: config.name,
          organization: config.is_role_cookbook? ? ROLE_COOKBOOKS : WRAPPER_COOKBOOKS
        }
      end

      def contents_api
        api.repos.contents
      end

      def api
        check_configuration
        @github ||= Github.new do |c|
          c.basic_auth = "#{ENV['GITHUB_USERNAME']}:#{ENV['GITHUB_PERSONAL_TOKEN']}"
          c.endpoint = ET_GITHUB_API
          c.site = ET_GITHUB
        end
      end

      def check_configuration
        unless ENV['GITHUB_USERNAME']
          UI.error("Please ensure the GITHUB_USERNAME environment variable is set before running Github tasks.")
          exit
        end
        unless ENV['GITHUB_PERSONAL_TOKEN']
          UI.error("Please ensure the GITHUB_PERSONAL_TOKEN environment variable is set before running Github tasks. A personal token can be obtained from your Github account settings.")
          exit
        end
      end

    end
  end
end
