# frozen_string_literal: true

require_relative '../base_command'

module Sambot
  module Tasks
    class Create < BaseCommand

      NAME_REQUEST = ' What is the name of this cookbook?'

      PLATFORM_REQUEST = ' What operating system will this cookbook run on?'

      DESCRIPTION_REQUEST = ' What does this cookbook do?'

      PLATFORM_OPTIONS = %w[windows centos both]

      IDENTIFIER_REQUEST = ' What will be the unique machiner identifier for this role cookbook i.e. TCA (TeamCity Agent) or RMQ (RabbitMQ role)?'

      no_commands do

        def run(options)
          opts = {
            'name' => ask(NAME_REQUEST),
            'platforms' => ask(PLATFORM_REQUEST, limited_to: PLATFORM_OPTIONS),
            'description' => ask(DESCRIPTION_REQUEST)
          }
          check_cookbook_name(opts['name'])
          opts['identifier'] = ask(IDENTIFIER_REQUEST) if is_valid_role_name?(opts['name'])
          opts['platforms'] = normalize_platforms(opts['platforms'])
          Chef::Cookbook.create(Config.new(opts))
        end

        def normalize_platforms(platforms)
          platforms == 'both' ? PLATFORM_OPTIONS - ['both']: [platforms]
        end

        def check_cookbook_name(name)
          unless is_valid_name?(name)
            UI.error('The cookbook name you have provided is invalid')
            exit 1
          end
        end

        def is_valid_role_name?(name)
          name.start_with?('as-role-') || name.start_with?('as-app-role-')
        end

        def is_valid_name?(name)
          is_valid_role_name?(name)|| name.start_with?('as-')
        end

      end
    end
  end
end
